summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/timespinbox.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/timespinbox.cpp')
-rw-r--r--kstars/kstars/timespinbox.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kstars/kstars/timespinbox.cpp b/kstars/kstars/timespinbox.cpp
index 828e0330..72549f9b 100644
--- a/kstars/kstars/timespinbox.cpp
+++ b/kstars/kstars/timespinbox.cpp
@@ -37,8 +37,8 @@
#define SIDEREAL_YEAR 31558149.77
#define TROPICAL_YEAR 31556925.19
-TimeSpinBox::TimeSpinBox( TQWidget *tqparent, const char *name, bool _daysonly )
- : TQSpinBox ( -41, 41, 1 /* step */, tqparent, name )
+TimeSpinBox::TimeSpinBox( TQWidget *parent, const char *name, bool _daysonly )
+ : TQSpinBox ( -41, 41, 1 /* step */, parent, name )
{
setValidator( 0 );
setButtonSymbols( TQSpinBox::PlusMinus );